@@ -211,8 +211,7 @@ class Dataset():
         if example_img not in self.images:
             self.load_image(example_img)
 
-        # by default all images are in RGB
-        return cv2.cvtColor(cv2.imdecode(np.frombuffer(self.images[example_img], dtype=np.uint8), cv2.IMREAD_COLOR), cv2.COLOR_BGR2RGB)
+        return cv2.imdecode(np.frombuffer(self.images[example_img], dtype=np.uint8), cv2.IMREAD_COLOR)
 
 
     def get_train_subsets(self, shuffle=True):
